pub struct PersesConfigSecurityAuthentication {
pub access_token_ttl: Option<String>,
pub disable_sign_up: bool,
pub providers: PersesConfigSecurityAuthenticationProviders,
pub refresh_token_ttl: Option<String>,
}Expand description
Authentication contains configuration regarding management of access/refresh token
Fields
access_token_ttl: Option<String>AccessTokenTTL is the time to live of the access token. By default, it is 15 minutes.
disable_sign_up: boolDisableSignUp deactivates the Sign-up page in the UI. It also disables the endpoint that gives the possibility to create a user.
providers: PersesConfigSecurityAuthenticationProvidersProviders configure the different authentication providers
refresh_token_ttl: Option<String>RefreshTokenTTL is the time to live of the refresh token. The refresh token is used to get a new access token when it is expired. By default, it is 24 hours.