pub struct PersesConfigSecurityAuthenticationProvidersOauthHttpTlsConfig {
pub ca: Option<String>,
pub ca_file: Option<String>,
pub cert: Option<String>,
pub cert_file: Option<String>,
pub insecure_skip_verify: Option<bool>,
pub key: Option<String>,
pub key_file: Option<String>,
pub max_version: Option<String>,
pub min_version: Option<String>,
pub server_name: Option<String>,
}Fields
ca: Option<String>Text of the CA cert to use for the targets.
ca_file: Option<String>The CA cert to use for the targets.
cert: Option<String>Text of the client cert file for the targets.
cert_file: Option<String>The client cert file for the targets.
insecure_skip_verify: Option<bool>Disable target certificate validation.
key: Option<String>Text of the client key file for the targets.
key_file: Option<String>The client key file for the targets.
max_version: Option<String>Maximum acceptable TLS version. Accepted values: TLS10 (TLS 1.0), TLS11 (TLS 1.1), TLS12 (TLS 1.2), TLS13 (TLS 1.3). If unset, Perses will use Go default maximum version, which is TLS 1.3. See MaxVersion in https://pkg.go.dev/crypto/tls#Config.
min_version: Option<String>Minimum acceptable TLS version. Accepted values: TLS10 (TLS 1.0), TLS11 (TLS 1.1), TLS12 (TLS 1.2), TLS13 (TLS 1.3). If unset, Perses will use Go default minimum version, which is TLS 1.2. See MinVersion in https://pkg.go.dev/crypto/tls#Config.
server_name: Option<String>Used to verify the hostname for the targets.