pub struct PersesConfigDatasource {
pub disable_local: bool,
pub global: PersesConfigDatasourceGlobal,
pub project: PersesConfigDatasourceProject,
}Expand description
Datasource contains the configuration for the datasource.
Fields
disable_local: boolDisableLocal when used is preventing the possibility to add a datasource directly in the dashboard spec. It will also disable the associated proxy.
global: PersesConfigDatasourceGlobalproject: PersesConfigDatasourceProjectTrait Implementations
Sourceimpl Clone for PersesConfigDatasource
impl Clone for PersesConfigDatasource
Sourcefn clone(&self) -> PersesConfigDatasource
fn clone(&self) -> PersesConfigDatasource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PersesConfigDatasource
impl Debug for PersesConfigDatasource
Sourceimpl Default for PersesConfigDatasource
impl Default for PersesConfigDatasource
Sourcefn default() -> PersesConfigDatasource
fn default() -> PersesConfigDatasource
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PersesConfigDatasource
impl<'de> Deserialize<'de> for PersesConfigDatasource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PersesConfigDatasource
impl PartialEq for PersesConfigDatasource
Sourcefn eq(&self, other: &PersesConfigDatasource) -> bool
fn eq(&self, other: &PersesConfigDatasource) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PersesConfigDatasource
impl Serialize for PersesConfigDatasource
impl StructuralPartialEq for PersesConfigDatasource