pub struct PersesConfigVariableProject {
pub disable: bool,
}Fields
disable: boolDisable is used to disable the project variable feature. Note that if the global datasource and the project datasource are disabled, then the project variable will also be disabled.